@@ -4,14 +4,18 @@ from unittest import TestCase
 from ..command import CommandRunner
 from ..repository import GithubRepository
 from ..tests import network, requires_nix_build
-from . import PrefetchOptions, UrlHasherImpl, detect_actual_hash_from_nix_output
+from .nix_build import (
+    NixBuildUrlHasherImpl,
+    PrefetchOptions,
+    detect_actual_hash_from_nix_output,
+)
 
 
 @requires_nix_build
 @network
 class UrlHasherTests(TestCase):
     def setUp(self) -> None:
-        self.hasher = UrlHasherImpl(
+        self.hasher = NixBuildUrlHasherImpl(
             command_runner=CommandRunner(getLogger(__name__)), logger=getLogger()
         )
         self.repository = GithubRepository(
@@ -54,7 +58,7 @@ class UrlHasherTests(TestCase):
             revision=self.revision,
             prefetch_options=prefetch_options,
         )
-        self.assertNotEqual(hash_sum, "B5AlNwg6kbcaqUiQEC6jslCRKVpErXLMsKC+b9aPlrM=")
+        self.assertEqual(hash_sum, "gBAtCILDbqofa6+9/bXR9drxymCGrgwf0+5mDxwF9p0=")
 
 
 class DetectActualHashFromNixOutputTests(TestCase):
